# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_role_binding import ResourceListRoleBinding

class TestResourceListRoleBinding(unittest.TestCase):
    """ResourceListRoleBinding unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListRoleBinding:
        """Test ResourceListRoleBinding
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListRoleBinding`
        """
        model = ResourceListRoleBinding()
        if include_optional:
            return ResourceListRoleBinding(
                records = [
                    arthur_client.api_bindings.models.role_binding.RoleBinding(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        role = arthur_client.api_bindings.models.bound_role.BoundRole(
                            id = '', 
                            name = '', ), 
                        bound_resource_kind = 'organization', 
                        bound_resource = arthur_client.api_bindings.models.bound_resource.BoundResource(
                            id = '', 
                            name = '', 
                            metadata = arthur_client.api_bindings.models.project_bound_resource_metadata.ProjectBoundResourceMetadata(
                                workspace_id = '', 
                                workspace_name = '', ), ), 
                        bound_member_kind = 'user', 
                        bound_member = arthur_client.api_bindings.models.bound_member.BoundMember(
                            id = '', 
                            name = '', ), )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListRoleBinding(
                records = [
                    arthur_client.api_bindings.models.role_binding.RoleBinding(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        role = arthur_client.api_bindings.models.bound_role.BoundRole(
                            id = '', 
                            name = '', ), 
                        bound_resource_kind = 'organization', 
                        bound_resource = arthur_client.api_bindings.models.bound_resource.BoundResource(
                            id = '', 
                            name = '', 
                            metadata = arthur_client.api_bindings.models.project_bound_resource_metadata.ProjectBoundResourceMetadata(
                                workspace_id = '', 
                                workspace_name = '', ), ), 
                        bound_member_kind = 'user', 
                        bound_member = arthur_client.api_bindings.models.bound_member.BoundMember(
                            id = '', 
                            name = '', ), )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListRoleBinding(self):
        """Test ResourceListRoleBinding"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.datasets_v1_api import DatasetsV1Api


class TestDatasetsV1Api(unittest.TestCase):
    """DatasetsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = DatasetsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_dataset(self) -> None:
        """Test case for delete_dataset

        Delete Dataset
        """
        pass

    def test_get_available_dataset(self) -> None:
        """Test case for get_available_dataset

        Get Available Dataset By Id
        """
        pass

    def test_get_connector_available_datasets(self) -> None:
        """Test case for get_connector_available_datasets

        Get Available Datasets By Connector Id
        """
        pass

    def test_get_connector_datasets(self) -> None:
        """Test case for get_connector_datasets

        Get Datasets By Connector Id
        """
        pass

    def test_get_dataset(self) -> None:
        """Test case for get_dataset

        Get Dataset By Id
        """
        pass

    def test_get_datasets(self) -> None:
        """Test case for get_datasets

        Get Datasets
        """
        pass

    def test_get_datasets_in_workspace(self) -> None:
        """Test case for get_datasets_in_workspace

        Get Workspace Datasets.
        """
        pass

    def test_patch_dataset(self) -> None:
        """Test case for patch_dataset

        Update Dataset
        """
        pass

    def test_post_available_dataset(self) -> None:
        """Test case for post_available_dataset

        Create Single Available Dataset
        """
        pass

    def test_post_connector_dataset(self) -> None:
        """Test case for post_connector_dataset

        Create Connector Dataset
        """
        pass

    def test_post_project_available_dataset(self) -> None:
        """Test case for post_project_available_dataset

        Create Project Available Dataset
        """
        pass

    def test_post_project_dataset(self) -> None:
        """Test case for post_project_dataset

        Create Project Dataset
        """
        pass

    def test_put_available_dataset_schema(self) -> None:
        """Test case for put_available_dataset_schema

        Update Available Dataset Schema
        """
        pass

    def test_put_connector_available_datasets(self) -> None:
        """Test case for put_connector_available_datasets

        Overwrite Connector Available Datasets
        """
        pass

    def test_put_dataset_schema(self) -> None:
        """Test case for put_dataset_schema

        Update Dataset Schema
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.connector_pagination_options import ConnectorPaginationOptions
from arthur_client.api_bindings.models.data_result_filter import DataResultFilter
from typing import Optional, Set
from typing_extensions import Self

class PostDataRetrievalOperation(BaseModel):
    """
    PostDataRetrievalOperation
    """ # noqa: E501
    start_timestamp: datetime = Field(description="Start timestamp to retrieve data for.")
    end_timestamp: datetime = Field(description="End timestamp to retrieve data for.")
    data_retrieval_filters: Optional[List[DataResultFilter]] = Field(default=None, description="Filters to apply to retrieved data")
    pagination_options: Optional[ConnectorPaginationOptions] = Field(default=None, description="Pagination options to apply to retrieved data")
    __properties: ClassVar[List[str]] = ["start_timestamp", "end_timestamp", "data_retrieval_filters", "pagination_options"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PostDataRetrievalOperation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data_retrieval_filters (list)
        _items = []
        if self.data_retrieval_filters:
            for _item_data_retrieval_filters in self.data_retrieval_filters:
                if _item_data_retrieval_filters:
                    _items.append(_item_data_retrieval_filters.to_dict())
            _dict['data_retrieval_filters'] = _items
        # override the default output from pydantic by calling `to_dict()` of pagination_options
        if self.pagination_options:
            _dict['pagination_options'] = self.pagination_options.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PostDataRetrievalOperation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "start_timestamp": obj.get("start_timestamp"),
            "end_timestamp": obj.get("end_timestamp"),
            "data_retrieval_filters": [DataResultFilter.from_dict(_item) for _item in obj["data_retrieval_filters"]] if obj.get("data_retrieval_filters") is not None else None,
            "pagination_options": ConnectorPaginationOptions.from_dict(obj["pagination_options"]) if obj.get("pagination_options") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.data_retrieval_v1_api import DataRetrievalV1Api


class TestDataRetrievalV1Api(unittest.TestCase):
    """DataRetrievalV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = DataRetrievalV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_available_data_retrieval_data(self) -> None:
        """Test case for delete_available_data_retrieval_data

        Delete Retrieved Data
        """
        pass

    def test_delete_data_retrieval_data(self) -> None:
        """Test case for delete_data_retrieval_data

        Delete Retrieved Data
        """
        pass

    def test_get_available_data_retrieval_data(self) -> None:
        """Test case for get_available_data_retrieval_data

        Gets Raw Data Operation Data
        """
        pass

    def test_get_data_retrieval_data(self) -> None:
        """Test case for get_data_retrieval_data

        Gets Raw Data Operation Data
        """
        pass

    def test_post_available_data_retrieval_operation(self) -> None:
        """Test case for post_available_data_retrieval_operation

        Create Raw Data Operation
        """
        pass

    def test_post_data_retrieval_operation(self) -> None:
        """Test case for post_data_retrieval_operation

        Create Raw Data Operation
        """
        pass

    def test_put_available_data_retrieval_data(self) -> None:
        """Test case for put_available_data_retrieval_data

        Put Retrieved Data
        """
        pass

    def test_put_data_retrieval_data(self) -> None:
        """Test case for put_data_retrieval_data

        Put Retrieved Data
        """
        pass


if __name__ == '__main__':
    unittest.main()
